#!/bin/bash
# maintainer         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# packager           : Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# packager           : guth-AT-ploposor.com
# source location    : http://encfs.googlecode.com/files/encfs-1.7-4.tgz

softname='encfs'
softversion='1.7.4'
packageversion='66.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tgz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://encfs.googlecode.com/files/$softname-$softversion.tgz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
encfs: encfs (Encrypted Filesystem)
encfs:
encfs: EncFS provides a pass-through encrypted filesystem in user-space. It
encfs: runs without any special permissions and uses the FUSE library and
encfs: Linux kernel module to provide the filesystem interface. Encfs is
encfs: meant to provide security against off-line attacks; ie your notebook
encfs: or backups fall into the wrong hands, etc.
encfs:
encfs:
encfs:
encfs:
EOF

# check if package is present
if [ -f $softname-$softversion.tgz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=/usr \
      --mandir=/usr/man \
      --program-prefix="" \
      --program-suffix="" \
      --build=$arch-slackware-linux

    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      ABOUT-NLS AUTHORS COPYING ChangeLog INSTALL README encfs/encfs-man.html \
      $dest/usr/doc/$softname-$softversion
      
# Compress Man & Info Pages
gzip -9 $dest/usr/man/man?/*

# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
/sbin/makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

echo "http://encfs.googlecode.com/files/encfs-1.6-1.tgz" > $package.src
echo "http://zen-repo.meticul.eu/zen_stuffs/guth/packages/encfs/build-encfs.sh" >> $package.src

echo -n "boost,cxxlibs|gcc-g++,fuse,gcc,openssl,rlog" > $package.dep

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
